# Tapr

---

## Installation

```pip install tapr```

---

## Introduction

Tapr facilitates what it stands for: TAbular PRogramming. In short what this means
is that it allows users to work with tabular objects called N-tables. N-tables
are n-dimensional tables (10/10 naming right?) that can contain any python object.
They provide a suite of operations that are "tabularized", which is a concept similar
to vectoraization and broadcasting in other table-oriented libraries like numpy,
pandas, and xarray. The same way these libraries get rid of the need for
loops on more primative data types, Tapr does so for any python data type.

---

## Documentation

You can find the Tapr documentation [here](https://tapr.readthedocs.io/).

---

## License

Tapr is distributed under the terms of the [MIT License](https://bitbucket.org/elspacedoge/tapr/src/master/LICENSE)